package com.alihealth.d2d.provtest.domain;

import com.alihealth.d2d.provtest.utils.LocalDateDeserializer;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlProperty;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;
import java.time.LocalDate;
import java.time.LocalDateTime;

/**
 * <p>
 * 药品生产许可证基本信息数据子集
 * </p>
 *
 * @author Jason
 * @since 2025-06-06
 */
@Getter
@Setter
@TableName("pharmaceutical_production_license_base_info")
public class PharmaceuticalProductionLicenseBaseInfo implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键ID
     */
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 事件流水号
     */
    private String eventId;

    /**
     * 生产许可证编号
     */
    @JacksonXmlProperty(localName = "SCXKZBH")
    private String scxkzbh;

    /**
     * 境内药品生产企业名称
     */
    @JacksonXmlProperty(localName = "JNYPSCQYMC")
    private String jnypscqymc;

    /**
     * 统一社会信用代码
     */
    @JacksonXmlProperty(localName = "TYSHXYDM")
    private String tyshxydm;

    /**
     * 注册地址
     */
    @JacksonXmlProperty(localName = "ZCDZ")
    private String zcdz;

    /**
     * 法定代表人
     */
    @JacksonXmlProperty(localName = "FDDBR")
    private String fddbr;

    /**
     * 企业负责人
     */
    @JacksonXmlProperty(localName = "QYFZR")
    private String qyfzr;

    /**
     * 质量负责人
     */
    @JacksonXmlProperty(localName = "ZLFZR")
    private String zlfzr;

    /**
     * 分类码
     */
    @JacksonXmlProperty(localName = "FLM")
    private String flm;

    /**
     * 有效期
     */
    @JacksonXmlProperty(localName = "YXQ")
    @JsonDeserialize(using = LocalDateDeserializer.class)
    private LocalDate yxq;

    /**
     * 生产地址
     */
    @JacksonXmlProperty(localName = "SCDZ")
    private String scdz;

    /**
     * 生产范围
     */
    @JacksonXmlProperty(localName = "SCFW")
    private String scfw;

    /**
     * 发证机关
     */
    @JacksonXmlProperty(localName = "FZJG")
    private String fzjg;

    /**
     * 签发人
     */
    @JacksonXmlProperty(localName = "QFR")
    private String qfr;

    /**
     * 签发日期
     */
    @JacksonXmlProperty(localName = "QFRQ")
    @JsonDeserialize(using = LocalDateDeserializer.class)
    private LocalDate qfrq;

    /**
     * 日常监督管理机构
     */
    @JacksonXmlProperty(localName = "RCJDGLJG")
    private String rcjdgljg;

    /**
     * 投诉举报电话
     */
    @JacksonXmlProperty(localName = "SCJBDH")
    private String scjbdh;

    /**
     * 创建时间
     */
    private LocalDateTime createTime;

    /**
     * 更新时间
     */
    private LocalDateTime updateTime;

    /**
     * 是否删除(0-否 1-是)
     */
    private Integer isDeleted;


}
